/*
    Copyright (c) 2013 Boldizsár Lipka <lipkab@zoho.com>

    This file is part of the Apertium Visual Rule Editor.

    Apertium Visual Rule Editor is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Apertium Visual Rule Editor is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Apertium Visual Rule Editor.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef FILETAB_H
#define FILETAB_H

#include <QWidget>
#include <QVector>

#include "node.h"
#include "sectiontab.h"

namespace Ui {
class FileTab;
}

class FileTab : public QWidget
{
    Q_OBJECT
    
public:
    explicit FileTab(QWidget *parent, Node* root, const QString& path = "");
    ~FileTab();

    int sectionCount() const { return sections_.size(); }
    QString sectionTitle(int index) const { return sections_[index].first; }
    SectionTab* sectionTab(int index) const { return sections_[index].second; }

    const QString& filePath() const { return filePath_; }
    void setFilePath(const QString& path) { filePath_ = path; }

    QString fileName() const;

    Node* rootNode() const { return fileRoot_; }
    void setRootNode(Node* n) { fileRoot_ = n; }

    ActionStack* currentActionStack();

    SectionTab* currentSection();

    bool isSaved() const { return saved_; }

public slots:
    void setUnsaved() { saved_ = false; emit saveStateChanged(false); }
    void setSaved() { saved_ = true; emit saveStateChanged(true); }

signals:
    void sectionChanged();
    void saveStateChanged(bool);

private slots:
    void on_sectionsContainer_currentChanged();

private:
    Ui::FileTab *ui;

    QVector<QPair<QString, SectionTab*> > sections_;
    Node* fileRoot_;
    QString filePath_;
    bool saved_;

};

#endif // FILETAB_H
